@@ -1,4 +1,3 @@
-#[macro_use]
 extern crate nom;
 #[macro_use]
 extern crate tracing;
@@ -48,6 +47,10 @@ pub struct U2FSignData {
 
 pub mod error;
 pub mod softtok;
+
+#[cfg(feature = "nfc")]
+pub mod nfc;
+#[cfg(feature = "u2fhid")]
 pub mod u2fhid;
 
 pub struct WebauthnAuthenticator<T>
@@ -365,13 +368,13 @@ where
         let aaguid: [u8; 16] = [0; 16];
 
         // make a 00 aaguid
-        let acd: Vec<u8> = aaguid
+        let khlen_be_bytes = key_handle_len.to_be_bytes();
+        let acd_iter = aaguid
             .iter()
-            .chain(key_handle_len.to_be_bytes().iter())
+            .chain(khlen_be_bytes.iter())
             .copied()
             .chain(u2rd.key_handle.iter().copied())
-            .chain(pk_cbor_bytes.iter().copied())
-            .collect();
+            .chain(pk_cbor_bytes.iter().copied());
 
         // set counter to 0 during create
         // Combine rp_id_hash, flags, counter, acd, into authenticator data.
@@ -386,7 +389,7 @@ where
                 // A 0 u32 counter
                 iter::repeat(0).take(4),
             )
-            .chain(acd.into_iter())
+            .chain(acd_iter)
             .collect();
 
         let mut attest_map = BTreeMap::new();
@@ -567,159 +570,3 @@ where
         })
     }
 }
-
-#[cfg(test)]
-mod tests {
-    use crate::softtok::U2FSoft;
-    use crate::u2fhid::U2FHid;
-    use crate::WebauthnAuthenticator;
-    use webauthn_rs::ephemeral::WebauthnEphemeralConfig;
-    use webauthn_rs::Webauthn;
-
-    /*
-    pub const CHALLENGE_SIZE_BYTES: usize = 32;
-
-    #[test]
-    fn webauthn_authenticator_basic_registration() {
-        let _ = tracing_subscriber::fmt().try_init();
-        let chal = CreationChallengeResponse {
-            public_key: PublicKeyCredentialCreationOptions {
-                rp: RelyingParty {
-                    name: "WebauthenAuthticatorRs".to_string(),
-                    id: "localhost".to_string(),
-                },
-                user: User {
-                    id: Base64UrlSafeData(
-                        base64::decode("d2lsbGlhbQ==").unwrap()
-                    ),
-                    name: "william".to_string(),
-                    display_name: "William".to_string(),
-                },
-                challenge: Base64UrlSafeData(
-                    (0..CHALLENGE_SIZE_BYTES).map(|_| 0).collect::<Vec<u8>>()
-                ),
-                pub_key_cred_params: vec![
-                    PubKeyCredParams {
-                        type_: "public-key".to_string(),
-                        alg: -7,
-                    }
-                ],
-                timeout: Some(60000),
-                attestation: Some(AttestationConveyancePreference::None),
-                exclude_credentials: None,
-                authenticator_selection: Some(AuthenticatorSelectionCriteria{
-                    authenticator_attachment: None,
-                    require_resident_key: false,
-                    user_verification: UserVerificationPolicy::Discouraged,
-                }),
-                extensions: None,
-            }
-        };
-
-        let wa = WebauthnAuthenticator::new();
-        let r = wa.do_registration("https://localhost", chal)
-            .map_err(|e| {
-                error!("Error -> {:x?}", e);
-                e
-            })
-            .expect("Failed to register");
-
-    }
-    */
-
-    #[test]
-    fn webauthn_authenticator_wan_u2fhid_interact() {
-        let _ = tracing_subscriber::fmt().try_init();
-
-        let wan_c = WebauthnEphemeralConfig::new(
-            "https://localhost:8080/auth",
-            "https://localhost:8080",
-            "localhost",
-            None,
-        );
-
-        let wan = Webauthn::new(wan_c);
-
-        let username = "william".to_string();
-
-        let (chal, reg_state) = wan.generate_challenge_register(&username, false).unwrap();
-
-        println!("🍿 challenge -> {:x?}", chal);
-
-        let mut wa = WebauthnAuthenticator::new(U2FHid::new());
-        let r = wa
-            .do_registration("https://localhost:8080", chal)
-            .map_err(|e| {
-                error!("Error -> {:x?}", e);
-                e
-            })
-            .expect("Failed to register");
-
-        let (cred, _reg_data) = wan
-            .register_credential(&r, &reg_state, |_| Ok(false))
-            .unwrap();
-
-        let (chal, auth_state) = wan.generate_challenge_authenticate(vec![cred]).unwrap();
-
-        let r = wa
-            .do_authentication("https://localhost:8080", chal)
-            .map_err(|e| {
-                error!("Error -> {:x?}", e);
-                e
-            })
-            .expect("Failed to auth");
-
-        let auth_res = wan
-            .authenticate_credential(&r, &auth_state)
-            .expect("webauth authentication denied");
-        info!("auth_res -> {:x?}", auth_res);
-    }
-
-    #[test]
-    fn webauthn_authenticator_wan_softtoken() {
-        let _ = tracing_subscriber::fmt().try_init();
-
-        let wan_c = WebauthnEphemeralConfig::new(
-            "https://localhost:8080/auth",
-            "https://localhost:8080",
-            "localhost",
-            None,
-        );
-
-        let wan = Webauthn::new(wan_c);
-
-        let username = "william".to_string();
-
-        let (chal, reg_state) = wan.generate_challenge_register(&username, false).unwrap();
-
-        println!("🍿 challenge -> {:x?}", chal);
-
-        let mut wa = WebauthnAuthenticator::new(U2FSoft::new());
-        let r = wa
-            .do_registration("https://localhost:8080", chal)
-            .map_err(|e| {
-                error!("Error -> {:x?}", e);
-                e
-            })
-            .expect("Failed to register");
-
-        let (cred, _reg_data) = wan
-            .register_credential(&r, &reg_state, |_| Ok(false))
-            .unwrap();
-
-        let (chal, auth_state) = wan.generate_challenge_authenticate(vec![cred]).unwrap();
-
-        let r = wa
-            .do_authentication("https://localhost:8080", chal)
-            .map_err(|e| {
-                error!("Error -> {:x?}", e);
-                e
-            })
-            .expect("Failed to auth");
-
-        let auth_res = wan
-            .authenticate_credential(&r, &auth_state)
-            .expect("webauth authentication denied");
-        info!("auth_res -> {:x?}", auth_res);
-    }
-}
